@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,8 +14,9 @@
 import logging
 
 # Enthought library imports.
-from traits.api import Event, HasTraits, Instance, List, provides
-from traits.api import on_trait_change
+from traits.api import (
+    Event, HasTraits, Instance, List, observe, on_trait_change, provides,
+)
 
 # Local imports.
 from .i_application import IApplication
@@ -59,12 +60,12 @@ class CompositePluginManager(HasTraits):
     # The application that the plugin manager is part of.
     application = Instance(IApplication)
 
-    def _application_changed(self, trait_name, old, new):
+    @observe("application")
+    def _update_application(self, event):
+        new = event.new
         for plugin_manager in self.plugin_managers:
             plugin_manager.application = new
 
-        return
-
     # The plugin managers that make up this plugin manager!
     #
     # This is currently a list of 'PluginManager's as opposed to, the more
@@ -74,7 +75,7 @@ class CompositePluginManager(HasTraits):
     plugin_managers = List(PluginManager)
 
     @on_trait_change("plugin_managers[]")
-    def _update_application(self, obj, trait_named, removed, added):
+    def _update_application_on_plugins(self, obj, trait_named, removed, added):
         for plugin_manager in removed:
             plugin_manager.application = self.application
 
@@ -144,8 +145,6 @@ class CompositePluginManager(HasTraits):
         for plugin in self:
             self.start_plugin(plugin)
 
-        return
-
     def start_plugin(self, plugin=None, plugin_id=None):
         """ Start the specified plugin. """
 
@@ -158,8 +157,6 @@ class CompositePluginManager(HasTraits):
         else:
             raise SystemError("no such plugin %s" % plugin_id)
 
-        return
-
     def stop(self):
         """ Stop the plugin manager. """
 
@@ -170,8 +167,6 @@ class CompositePluginManager(HasTraits):
         for plugin in stop_order:
             self.stop_plugin(plugin)
 
-        return
-
     def stop_plugin(self, plugin=None, plugin_id=None):
         """ Stop the specified plugin. """
 
@@ -183,5 +178,3 @@ class CompositePluginManager(HasTraits):
 
         else:
             raise SystemError("no such plugin %s" % plugin_id)
-
-        return
